richardview package
===================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   richardview._system
   richardview.built_in_widgets
   richardview.majumdar_lab_widgets
   richardview.utilities

Submodules
----------

.. toctree::
   :maxdepth: 4

   richardview.dashboard
   richardview.generic_serial_emulator
   richardview.generic_widget
   richardview.minimal_widget

Module contents
---------------

.. automodule:: richardview
   :members:
   :undoc-members:
   :show-inheritance:
   :private-members:
